@@ -17,7 +17,7 @@ class PatchReviewBehaviour(vcsreview.PatchReviewBehaviour):
     """
     def reviewers_rset(self):
         rset = self._cw.execute(
-            'DISTINCT Any U '
+            'DISTINCT Any U, "" '
             'WHERE P eid %(p)s, '
             '      P patch_ticket T, '
             '      PS patch_ticket T, '
