@@ -186,7 +186,7 @@ class PatchRevisionAdded(hook.Hook):
 # depending on trackervcs/forge import order. Import order is fixed using
 # __pkginfo__.__recommends__ so everything should be ok
 tracker.S_RELS.add('source_repository')
-
+tracker.O_RELS |= set(('from_repository', 'from_revision'))
 
 # registration control #########################################################
 
@@ -201,8 +201,8 @@ def registration_callback(vreg):
     if 'vcreview' in vreg.config.cubes():
         vreg.register(PatchLinkedToTicket)
         vreg.register(PatchRevisionAdded)
-        # security propagation #################################################
-        tracker.S_RELS |= set(('patch_revision', 'has_activity', ))
-        tracker.O_RELS |= set(('point_of',))
+        # vcreview permission propagation ######################################
+        tracker.S_RELS |= set(('has_activity', ))
+        tracker.O_RELS |= set(('patch_revision', 'point_of',))
     if 'apycot' in vreg.config.cubes():
         vreg.register(ApycotEnvironmentAdded)
