@@ -58,9 +58,9 @@ class VersionPatchesTab(EntityView):
         lambda x: x.project.source_repository and x.project.source_repository[0].has_review)
 
     def entity_call(self, entity):
-        rql = ('Any P,PO,P,P,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS '
+        rql = ('Any P,GROUP_CONCAT(PO),P,P,PB,PS GROUPBY P,PB,PS '
                'WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
-               'TR? wf_info_for P, RE from_repository R, P patch_ticket T, '
+               'RE from_repository R, P patch_ticket T, '
                'T done_in V, V eid %(v)s')
         rset = self._cw.execute(rql, {'v': entity.eid})
         self.wview('vcreview.patches.table', rset, 'noresult')
@@ -87,26 +87,26 @@ def registration_callback(vreg):
 
     vreg.register_all(globals().values(), __name__)
 
-    # overridde vcreview summary tables to include patch's ticket and ticket's
+    # override vcreview summary tables to include patch's ticket and ticket's
     # version
     vcreview_startup.AllActivePatches.rql = (
-        'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
-        'ORDERBY RT,PB,PO WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
-        'TR? wf_info_for P, RE from_repository R, R title RT, '
+        'Any P,GROUP_CONCAT(PO),P,P,PB,PS,R,T,V GROUPBY R,P,PB,PS,T,V '
+        'ORDERBY RT,PB WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
+        'RE from_repository R, R title RT, '
         'NOT PS name %s, '
         'P patch_ticket T?, T done_in V?')
     vcreview_startup.UserWorkList.rql = (
-        'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
-        'ORDERBY RT,PB,PO WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS,'
-        'TR? wf_info_for P, RE from_repository R, R title RT, U eid %(u)s, '
+        'Any P,GROUP_CONCAT(PO),P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PB,PS,T,V '
+        'ORDERBY RT,PB WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS,'
+        'RE from_repository R, R title RT, U eid %(u)s, '
         'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
         'OR EXISTS(PS name "reviewed" AND P patch_committer U) '
         'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer U) '
         '    AND (EXISTS(R repository_committer U) OR EXISTS(U in_group G, G name "committers")))), '
         'P patch_ticket T?, T done_in V?')
     vcreview_primary.RepositoryPatchesTable.rql = (
-        'Any P,PO,P,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
-        'P patch_revision RE, RE author PO, RE branch PB, P in_state PS, TR? wf_info_for P, '
+        'Any P,GROUP_CONCAT(PO),P,PB,PS,T,V GROUPBY P,PB,PS,T,V WHERE '
+        'P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
         'RE from_repository R, R eid %(x)s, '
         'P patch_ticket T?, T done_in V?')
     # add a tab on project view to display patches
